@@ -1,7 +1,7 @@
 .runThisTest <- Sys.getenv("RunAllinsightTests") == "yes"
 
 if (.runThisTest || Sys.getenv("USER") == "travis") {
-  if (require("testthat") && require("insight") && require("glmmTMB")) {
+  if (requiet("testthat") && requiet("insight") && requiet("glmmTMB")) {
     m1 <- download_model("glmmTMB_spatial_1")
 
     test_that("find_weights", {
@@ -77,7 +77,8 @@ if (.runThisTest || Sys.getenv("USER") == "travis") {
         list(
           conditional = as.formula("calcium ~ elevation + region"),
           random = as.formula("~pos + 0 | ID")
-        )
+        ),
+        ignore_attr = TRUE
       )
     })
 
